"""Bbh group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval.lm_task_extractors."

BBH_TASKS = {
    "bbh": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_boolean_expressions": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_causal_judgement": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_date_understanding": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_disambiguation_qa": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_dyck_languages": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_formal_fallacies": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_geometric_shapes": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_hyperbaton": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_logical_deduction_five_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_logical_deduction_seven_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_logical_deduction_three_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_movie_recommendation": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_multistep_arithmetic_two": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_navigate": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_object_counting": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_penguins_in_a_table": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_reasoning_about_colored_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_ruin_names": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_salient_translation_error_detection": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_snarks": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_sports_understanding": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_temporal_sequences": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_tracking_shuffled_objects_five_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_tracking_shuffled_objects_seven_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_tracking_shuffled_objects_three_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_web_of_lies": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_fewshot_word_sorting": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_boolean_expressions": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_causal_judgement": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_date_understanding": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_disambiguation_qa": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_dyck_languages": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_formal_fallacies": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_geometric_shapes": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_hyperbaton": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_logical_deduction_five_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_logical_deduction_seven_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_logical_deduction_three_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_movie_recommendation": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_multistep_arithmetic_two": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_navigate": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_object_counting": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_penguins_in_a_table": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_reasoning_about_colored_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_ruin_names": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_salient_translation_error_detection": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_snarks": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_sports_understanding": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_temporal_sequences": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_tracking_shuffled_objects_five_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_tracking_shuffled_objects_seven_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_tracking_shuffled_objects_three_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_web_of_lies": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_cot_zeroshot_word_sorting": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_boolean_expressions": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_causal_judgement": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_date_understanding": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_disambiguation_qa": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_dyck_languages": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_formal_fallacies": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_geometric_shapes": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_hyperbaton": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_logical_deduction_five_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_logical_deduction_seven_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_logical_deduction_three_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_movie_recommendation": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_multistep_arithmetic_two": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_navigate": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_object_counting": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_penguins_in_a_table": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_reasoning_about_colored_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_ruin_names": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_salient_translation_error_detection": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_snarks": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_sports_understanding": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_temporal_sequences": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_tracking_shuffled_objects_five_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_tracking_shuffled_objects_seven_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_tracking_shuffled_objects_three_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_web_of_lies": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_fewshot_word_sorting": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_boolean_expressions": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_causal_judgement": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_date_understanding": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_disambiguation_qa": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_dyck_languages": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_formal_fallacies": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_geometric_shapes": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_hyperbaton": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_logical_deduction_five_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_logical_deduction_seven_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_logical_deduction_three_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_movie_recommendation": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_multistep_arithmetic_two": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_navigate": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_object_counting": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_penguins_in_a_table": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_reasoning_about_colored_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_ruin_names": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_salient_translation_error_detection": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_snarks": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_sports_understanding": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_temporal_sequences": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_tracking_shuffled_objects_five_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_tracking_shuffled_objects_seven_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_tracking_shuffled_objects_three_objects": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_web_of_lies": f"{BASE_IMPORT}bbh:BBHExtractor",
    "bbh_zeroshot_word_sorting": f"{BASE_IMPORT}bbh:BBHExtractor",
}
