"""Darijammlu group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval.lm_task_extractors."

DARIJAMMLU_TASKS = {
    "darijammlu": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_accounting": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_ar_mmlu": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_ar_mmlu_tasks": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_arabic_language": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_arabic_language_(general)": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_arabic_language_(grammar)": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_biology": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_civics": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_computer_science": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_driving_test": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_economics": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_general_knowledge": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_geography": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_global_facts": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_high_school_european_history": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_high_school_geography": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_high_school_government_and_politics": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_high_school_psychology": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_high_school_statistics": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_high_school_world_history": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_history": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_human_aging": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_international_law": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_islamic_studies": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_jurisprudence": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_law": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_logical_fallacies": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_management": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_management_ar": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_marketing": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_math": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_mmlu": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_mmlu_tasks": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_moral_disputes": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_moral_scenarios": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_natural_science": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_nutrition": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_philosophy": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_philosophy_ar": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_physics": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_political_science": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_professional_law": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_professional_psychology": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_public_relations": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_security_studies": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_social_science": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_sociology": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
    "darijammlu_world_religions": f"{BASE_IMPORT}darijammlu:DarijammluExtractor",
}
